# Vendor Policy
Vendor packages...
- To ease the use of cpenv in environments that do not support
  pip.
- To ensure that cpenv itself is vendorable as a library.
- When packages are unavailable via pypi.

## Vendored Packages
appdirs==1.4.4
cachetools==3.1.1
certifi==2021.10.8
pyyaml==5.3.1
shotgun_api3==3.3.3
terminalsize - https://gist.github.com/jtriley/1108174
